durationtools.yield_all_prolation_rewrite_pairs_of_rational_in_cantor_diagonalized_order
========================================================================================

.. autofunction:: abjad.tools.durationtools.yield_all_prolation_rewrite_pairs_of_rational_in_cantor_diagonalized_order.yield_all_prolation_rewrite_pairs_of_rational_in_cantor_diagonalized_order
